7号房的礼物 (豆瓣)
Description: 7号房的礼物电影简介和剧情介绍,7号房的礼物影评、图片、预告片、影讯、论坛、在线购票
Keywords: 7号房的礼物,7번방의 선물,7号房的礼物影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.99豆瓣电影Top250

# 7号房的礼物 7번방의 선물 (2013)

导演: 李焕庆
编剧: 李焕庆 / 刘英雅
主演: 柳承龙 / 朴信惠 / 郑镇荣 / 金正泰 / 吴达洙 / 朴元尚 / 郑满植 / 葛素媛
类型: 剧情 / 喜剧 / 家庭
官方网站: www.7gift.kr
制片国家/地区: 韩国
语言: 韩语
上映日期: 2013-01-23(韩国)
片长: 127分钟
又名: 戆爸的礼物(港) / 7号囚房的礼物 / 12月23日 / Gift From Room / Find Miracle in Cell No.7 / Miracle In Cell No.7
IMDb: tt2659414
豆瓣评分
引用
8.9
527937人评价
5星
57.5%
4星
33.6%
3星
7.9%
2星
0.8%
1星
0.2%
好于 99% 喜剧片
好于 98% 剧情片
想看 看过
评价:
推荐

## 7号房的礼物的剧情简介 · · · · · ·

1997年，只有6岁儿童智商的智障男子李龙久（柳成龙 饰）和可爱的女儿艺胜（葛素媛 饰）相依为命，生活虽然简单清贫，却充满幸福。某天，执着为女儿买美少女战士书包的龙久意外卷入一起幼童诱拐奸杀案，而死者竟是警察局长的女儿。龙久懵懂无知，搞不清状况，昏头昏脑就被投入监狱。在7号牢房中，聚集着走私犯蘇杨浩（吴达洙 饰）、诈骗犯崔春浩（朴元尚 饰）、通奸犯姜万范（金正泰 饰）、恐吓犯老徐（金基灿 饰）和抢劫犯申奉植（郑万植 饰）等五毒俱全的“社会渣滓”。龙久孩子般纯洁的心渐渐感动了这几个“大坏蛋”，他们甚至不惜冒险将艺胜带入牢房与父亲相会。
黑暗冰冷的监牢内，7号牢房阳光满满…… ©豆瓣

## 7号房的礼物的演职员 · · · · · · ( 全部 27 )

- 李焕庆 导演
- 柳承龙 饰 李龙九
- 朴信惠 饰 李艺胜
- 郑镇荣 饰 科长
- 金正泰 饰 姜万范
- 吴达洙 饰 苏杨浩

## 7号房的礼物的视频和图片 · · · · · · ( 预告片7 | 视频评论1 · 添加 | 图片623 · 添加 )

## 7号房的礼物的获奖情况 · · · · · · ( 全部 )

- 第34届韩国电影青龙奖
- 最佳男主角(提名)
- 柳承龙

- 第49届百想艺术大赏
- 电影类 大赏
- 柳承龙

- 第50届韩国电影大钟奖
- 最佳影片(提名)

## 喜欢这部电影的人也喜欢 · · · · · ·

  饮食男女

  82年生的金智英

  寻梦环游记

  小偷家族

  岁月神偷

  亲爱的

  我是山姆

  海蒂和爷爷

  何以为家

  海街日记

我要写短评

## 7号房的礼物的短评 · · · · · · ( 全部 117830 条 )

热门 / 最新 / 好友

### 3350 有用 贝塔先生 看过 2013-04-18 21:09:15

我们目击的事实，往往只是浮出水面的冰凌，冰山下面的巨大事实，更排山倒海穿透视听。 我们直面的人生舞台，也许只是化蝶幻影，层层垂帘般幕后的故事，更震撼世道人心。

### 738 有用 影志 看过 2013-10-19 16:24:24

《我是山姆》的《美丽人生》

### 1049 有用 麦 看过 2013-05-15 01:11:09

韩片一定要这样吗！！！哭肿了都

### 2190 有用 麻绳 看过 2013-04-22 00:33:37

看这么虐心的电影我都没哭，可能真的没什么电影可以让我哭了。如果想挥泪解毒的，可以尝试一下，十有八九会哭个稀里哗啦的。电影不乏刻意之处，但胡椒芥末用量太足，不中招也难，中国要能拍出这种杀伤力的催泪弹来，票房十亿起。

### 1020 有用 卫斯理 看过 2013-10-22 02:45:15

里面有太多不现实的地方，故事的结局却又那么的现实。童话般的影片，让我大半夜看的哭到抽搐了。

> 更多短评 117830条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 7号房的礼物的影评 · · · · · · ( 全部 1309 条 )

热门 / 最新 / 好友
Paper 2013-05-11 17:48:56

## 你送的礼物，会不会太特别？

国人常常把韩国戏称为”棒子国“，我们常常看不起他们的所有，比如电视剧，矫情做作假；比如组合，娘炮没实力；比如食物，泡菜什么的；比如整容，满大街都是一样的脸；比如男人，世界上生殖器尺寸最短的国度。就是这些因素组成的棒子国，却又常常能给自诩天朝的我们当头一棒。 ... (展开)
1888 150 275回应 收起
kiki 2013-04-19 20:01:34

## 我爸爸是平凡到掉进人群就看不到的人可是我依然爱他

我爸爸真的是非常平凡的一个中年男人，嗜烟嗜酒，没有什么大作为，唯一擅长的是做饭，每次打电话回家说爸我晚上回来吃饭，他就会马上翻出冰箱里所有的肉食做一顿狠丰富的晚餐。 我经常和他吵架，因为他非常的固执，有时候喝了酒就会更加的固执某一些他看不顺眼的事，甚至... (展开)
390 27 86回应 收起
红色的月亮 2013-08-10 01:03:17

## 只能说是非常普通的一个片子

片子整体过分的童话化，没有什么广泛的启示和深度，只能算是闲暇之余用来消遣的小片子。本片故事简单，而且比较脱离现实，过分的理想化的描写也使得这个片子并不能真正深入人心，故作的煽情片段，李傻的最后呐喊确实勾人泪点，但是确实有点故意煽情的感觉。 当然片子应该是要主... (展开)
602 497 405回应 收起
DonyLu 2013-04-13 18:31:05

## 这个剧情简介其实是不对的

这篇影评可能有剧透

豆瓣的剧情简介说：讲述了在患有精神迟滞症状的父亲受到莫名犯罪指控之后，其女儿在法庭上为其做无罪辩护的故事。 这个剧情简介。。。。不对 首先，这不是莫名的指控，当时案发现场除了小女孩以外只有这位智障阿伯尼，基本上大家都会把他当做嫌疑犯来怀疑。 其次，他的女儿为... (展开)
197 46 66回应 收起
姥姥 2018-02-26 19:46:35

## 害怕你受到伤害所以选择死亡，没想到比死亡更恐惧的却是，从此再也不能陪伴你一起成长

这篇影评可能有剧透

电影的开头是长大成人后的艺胜拿着父亲当年的审判记录从那间牢房里走出来，当看到满天飞扬的雪花中被铁丝绊住的明黄色的热气球时，抬头望向天空，脸上露出了夹杂着思念以及如释重负的笑，往后便拉开了回忆的序幕。 “害怕你受到伤害所以选择死亡 没想到比死亡更恐惧的却是 从此... (展开)
139 1 22回应 收起
飘雪 2015-01-25 16:30:49

## 特别的礼物，特别的你

1997年，有智商障碍的李龙久执着于给女儿买一个美少女战士的书包，意外卷入一起女童诱拐奸杀案件，而死者的父亲是之前与李龙久有过矛盾的警察局长。在自身无法解释实情对方又是正义代表的双重因素下，李龙久被当做唯一嫌犯投入7号牢房。很正常的，初来乍到的李龙久被7号... (展开)
127 3 11回应 收起
美神经 2017-07-25 21:51:56

## 礼物

这篇影评可能有剧透

一个意外，一个为了私利的恶毒的人，一个被分开的家庭，一个打破了一个暗无天日的地方的石子，一个温暖了所有人心灵的天使。 一个只有6岁儿童智商的父亲龙久，有一个可爱的女儿艺胜。龙久待人彬彬有礼，却意外卷入一起幼童诱拐奸杀案，被关进了7号牢房。这里聚集着人们口中说的... (展开)
59 2 0回应 收起
酒酿小丸子 2017-05-24 23:25:04

## 阳光礼物

这篇影评可能有剧透

只有6岁儿童智商的智障男子李龙久和可爱的女儿艺胜相依为命，生活虽然简单清贫，却充满幸福。某天，执着为女儿买美少女战士书包的龙久意外卷入一起幼童诱拐奸杀案，而死者竟是警察局长的女儿。龙久懵懂无知，昏头昏脑就被投入监狱。在7号牢房中，聚集着走私犯苏杨浩、诈骗犯崔... (展开)
32 2 0回应 收起
轻寻到下绿 2018-04-17 22:05:57

## 《七号房的礼物》

影片主打父女亲情牌，叙事流畅，暗涌着对当时社会特权阶层的讽刺和有力的控诉。弱势群体不是那么容易被污蔑和忽悠，影片充满了生离死别的父女亲情，煽情不为过，女儿成年以后为父亲的正名更令人唏嘘不已。 影片最为让人难以面对的是智障的父亲和幼小的女儿相依为命偶然被无辜卷... (展开)
74 4 1回应 收起
小人鱼 2017-07-18 21:32:10

## 感人的父女情

这篇影评可能有剧透

《七号房的礼物》这部电影是很早之前看过的，最近又开始重温一次…… 智商只有6岁的龙九含冤入狱最多凶犯的第七号监狱，超级溺爱7岁女儿艺胜的龙九和女儿的亲情感动了同一房间的重犯，大家一起联手帮助小女儿进入监狱。虽然父亲龙九的智商停留在6岁，但是看着女儿露出的幸福微... (展开)
21 1 1回应 收起

> 更多影评 1309篇

添加新讨论

## 讨论区 · · · · · ·

韩国的主旋律 | 来自花生酱 | 1 回应 | 2022-11-18 01:50:35
这样的电影居然有8.8分？ | 来自gandolf | 29 回应 | 2022-11-18 00:33:27
太感人了，给我整哭了，我旁边的朋友没哭，我把他... | 来自我立刻听歌 | 1 回应 | 2022-11-15 23:34:23
温馨 | 来自XinXin |  | 2022-11-09 10:06:02
怎么看不了 | 来自豆友zssrNfPliI | 1 回应 | 2022-11-08 07:46:22

> 去这部影片的讨论区（全部211条）

## 关于《7号房的礼物》的问题 · · · · · · ( 全部33个 )

- 为什么对于无行为能力的弱智者没有司法程序上的照顾？ 9人回答
- 请问谁给这片子类型定成喜剧的？？？ 16人回答

> 全部33个问题

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 2013 豆瓣电影【口碑榜】 (影志)
- 【内牛满面】 (影志)
- 剧情扣人、故事性强、不闷的好电影 (影志)
- 自从爱上了精神病电影，我又活泼起来了 (meiya)

## 谁在看这部电影 · · · · · ·

- Yang
  1分钟前 看过
- 再见白丝
  2分钟前 想看
- -XYH🦐
  3分钟前 看过

890520人看过 / 268518人想看

订阅7号房的礼物的评论:
feed: rss 2.0